@@ -34,8 +34,6 @@ import org.apache.doris.flink.exception.DorisRuntimeException;
 import org.apache.doris.flink.exception.DorisSchemaChangeException;
 import org.apache.doris.flink.exception.IllegalArgumentException;
 import org.apache.doris.flink.exception.ShouldNeverHappenException;
-import org.apache.doris.flink.rest.models.Backend;
-import org.apache.doris.flink.rest.models.BackendRow;
 import org.apache.doris.flink.rest.models.BackendV2;
 import org.apache.doris.flink.rest.models.BackendV2.BackendRowV2;
 import org.apache.doris.flink.rest.models.QueryPlan;
@@ -217,7 +215,8 @@ public class RestService implements Serializable {
         return parseResponse(connection, logger);
     }
 
-    private static String parseResponse(HttpURLConnection connection, Logger logger)
+    @VisibleForTesting
+    public static String parseResponse(HttpURLConnection connection, Logger logger)
             throws IOException {
         if (connection.getResponseCode() != HttpStatus.SC_OK) {
             logger.warn(
@@ -278,8 +277,9 @@ public class RestService implements Serializable {
         List<String> nodes = Arrays.asList(feNodes.split(","));
         Collections.shuffle(nodes);
         for (String feNode : nodes) {
-            if (BackendUtil.tryHttpConnection(feNode)) {
-                return feNode;
+            String host = feNode.trim();
+            if (BackendUtil.tryHttpConnection(host)) {
+                return host;
             }
         }
         throw new DorisRuntimeException(
@@ -307,95 +307,6 @@ public class RestService implements Serializable {
         return nodes;
     }
 
-    /**
-     * choice a Doris BE node to request.
-     *
-     * @param options configuration of request
-     * @param logger slf4j logger
-     * @return the chosen one Doris BE node
-     * @throws IllegalArgumentException BE nodes is illegal
-     */
-    @VisibleForTesting
-    public static String randomBackend(
-            DorisOptions options, DorisReadOptions readOptions, Logger logger)
-            throws DorisException, IOException {
-        List<BackendRowV2> backends = getBackendsV2(options, readOptions, logger);
-        logger.trace("Parse beNodes '{}'.", backends);
-        if (backends == null || backends.isEmpty()) {
-            logger.error(ILLEGAL_ARGUMENT_MESSAGE, "beNodes", backends);
-            throw new IllegalArgumentException("beNodes", String.valueOf(backends));
-        }
-        Collections.shuffle(backends);
-        BackendRowV2 backend = backends.get(0);
-        return backend.getIp() + ":" + backend.getHttpPort();
-    }
-
-    public static String getBackend(
-            DorisOptions options, DorisReadOptions readOptions, Logger logger)
-            throws DorisRuntimeException {
-        try {
-            return randomBackend(options, readOptions, logger);
-        } catch (Exception e) {
-            throw new DorisRuntimeException("Failed to get backend via " + options.getFenodes(), e);
-        }
-    }
-
-    /**
-     * get Doris BE nodes to request.
-     *
-     * @param options configuration of request
-     * @param logger slf4j logger
-     * @return the chosen one Doris BE node
-     * @throws IllegalArgumentException BE nodes is illegal. This method is deprecated. Because it
-     *     needs ADMIN_PRIV to get backends, which is not suitable for common users. Use
-     *     getBackendsV2 instead
-     */
-    @Deprecated
-    @VisibleForTesting
-    static List<BackendRow> getBackends(
-            DorisOptions options, DorisReadOptions readOptions, Logger logger)
-            throws DorisException, IOException {
-        String feNodes = options.getFenodes();
-        String feNode = randomEndpoint(feNodes, logger);
-        String beUrl = "http://" + feNode + BACKENDS;
-        HttpGet httpGet = new HttpGet(beUrl);
-        String response = send(options, readOptions, httpGet, logger);
-        logger.info("Backend Info:{}", response);
-        List<BackendRow> backends = parseBackend(response, logger);
-        return backends;
-    }
-
-    @Deprecated
-    static List<BackendRow> parseBackend(String response, Logger logger)
-            throws DorisException, IOException {
-        ObjectMapper mapper = new ObjectMapper();
-        Backend backend;
-        try {
-            backend = mapper.readValue(response, Backend.class);
-        } catch (JsonParseException e) {
-            String errMsg = "Doris BE's response is not a json. res: " + response;
-            logger.error(errMsg, e);
-            throw new DorisException(errMsg, e);
-        } catch (JsonMappingException e) {
-            String errMsg = "Doris BE's response cannot map to schema. res: " + response;
-            logger.error(errMsg, e);
-            throw new DorisException(errMsg, e);
-        } catch (IOException e) {
-            String errMsg = "Parse Doris BE's response to json failed. res: " + response;
-            logger.error(errMsg, e);
-            throw new DorisException(errMsg, e);
-        }
-
-        if (backend == null) {
-            logger.error(SHOULD_NOT_HAPPEN_MESSAGE);
-            throw new ShouldNeverHappenException();
-        }
-        List<BackendRow> backendRows =
-                backend.getRows().stream().filter(v -> v.getAlive()).collect(Collectors.toList());
-        logger.debug("Parsing schema result is '{}'.", backendRows);
-        return backendRows;
-    }
-
     /**
      * get Doris BE nodes to request.
      *
@@ -404,6 +315,7 @@ public class RestService implements Serializable {
      * @return the chosen one Doris BE node
      * @throws IllegalArgumentException BE nodes is illegal
      */
+    @VisibleForTesting
     public static List<BackendRowV2> getBackendsV2(
             DorisOptions options, DorisReadOptions readOptions, Logger logger) {
         String feNodes = options.getFenodes();
@@ -454,14 +366,6 @@ public class RestService implements Serializable {
         BackendV2 backend;
         try {
             backend = mapper.readValue(response, BackendV2.class);
-        } catch (JsonParseException e) {
-            String errMsg = "Doris BE's response is not a json. res: " + response;
-            logger.error(errMsg, e);
-            throw new DorisRuntimeException(errMsg, e);
-        } catch (JsonMappingException e) {
-            String errMsg = "Doris BE's response cannot map to schema. res: " + response;
-            logger.error(errMsg, e);
-            throw new DorisRuntimeException(errMsg, e);
         } catch (IOException e) {
             String errMsg = "Parse Doris BE's response to json failed. res: " + response;
             logger.error(errMsg, e);
@@ -645,7 +549,7 @@ public class RestService implements Serializable {
         String queryPlanUri =
                 String.format(
                         QUERY_PLAN_API,
-                        options.getFenodes(),
+                        randomEndpoint(options.getFenodes(), logger),
                         tableIdentifier[0],
                         tableIdentifier[1]);
         HttpPost httpPost = new HttpPost(queryPlanUri);
@@ -684,14 +588,6 @@ public class RestService implements Serializable {
         QueryPlan queryPlan;
         try {
             queryPlan = mapper.readValue(response, QueryPlan.class);
-        } catch (JsonParseException e) {
-            String errMsg = "Doris FE's response is not a json. res: " + response;
-            logger.error(errMsg, e);
-            throw new DorisException(errMsg, e);
-        } catch (JsonMappingException e) {
-            String errMsg = "Doris FE's response cannot map to schema. res: " + response;
-            logger.error(errMsg, e);
-            throw new DorisException(errMsg, e);
         } catch (IOException e) {
             String errMsg = "Parse Doris FE's response to json failed. res: " + response;
             logger.error(errMsg, e);
