@@ -17,7 +17,7 @@
 
 package org.apache.doris.flink.serialization;
 
-import org.apache.flink.util.Preconditions;
+import org.apache.flink.annotation.VisibleForTesting;
 
 import org.apache.arrow.memory.RootAllocator;
 import org.apache.arrow.vector.BaseIntVector;
@@ -157,7 +157,8 @@ public class RowBatch {
         return offsetInRowBatch < readRowCount;
     }
 
-    private void addValueToRow(int rowIndex, Object obj) {
+    @VisibleForTesting
+    public void addValueToRow(int rowIndex, Object obj) {
         if (rowIndex > rowCountInOneBatch) {
             String errMsg =
                     "Get row offset: " + rowIndex + " larger than row size: " + rowCountInOneBatch;
@@ -175,8 +176,14 @@ public class RowBatch {
                 final String currentType = schema.get(col).getType();
                 for (int rowIndex = 0; rowIndex < rowCountInOneBatch; rowIndex++) {
                     boolean passed = doConvert(col, rowIndex, minorType, currentType, fieldVector);
-                    Preconditions.checkArgument(
-                            passed, typeMismatchMessage(currentType, minorType));
+                    if (!passed) {
+                        throw new java.lang.IllegalArgumentException(
+                                "FLINK type is "
+                                        + currentType
+                                        + ", but arrow type is "
+                                        + minorType.name()
+                                        + ".");
+                    }
                 }
             }
         } catch (Exception e) {
@@ -185,7 +192,8 @@ public class RowBatch {
         }
     }
 
-    private boolean doConvert(
+    @VisibleForTesting
+    public boolean doConvert(
             int col,
             int rowIndex,
             Types.MinorType minorType,
@@ -470,7 +478,8 @@ public class RowBatch {
         return true;
     }
 
-    private LocalDateTime getDateTime(int rowIndex, FieldVector fieldVector) {
+    @VisibleForTesting
+    public LocalDateTime getDateTime(int rowIndex, FieldVector fieldVector) {
         TimeStampMicroVector vector = (TimeStampMicroVector) fieldVector;
         if (vector.isNull(rowIndex)) {
             return null;
@@ -488,10 +497,16 @@ public class RowBatch {
         return dateTime;
     }
 
-    private String completeMilliseconds(String stringValue) {
+    @VisibleForTesting
+    public static String completeMilliseconds(String stringValue) {
         if (stringValue.length() == DATETIMEV2_PATTERN.length()) {
             return stringValue;
         }
+
+        if (stringValue.length() < DATETIME_PATTERN.length()) {
+            return stringValue;
+        }
+
         StringBuilder sb = new StringBuilder(stringValue);
         if (stringValue.length() == DATETIME_PATTERN.length()) {
             sb.append(".");
