@@ -31,4 +31,6 @@ public class LoadConstants {
     public static final String NULL_VALUE = "\\N";
     public static final String DORIS_DELETE_SIGN = "__DORIS_DELETE_SIGN__";
     public static final String READ_JSON_BY_LINE = "read_json_by_line";
+    public static final String GROUP_COMMIT = "group_commit";
+    public static final String GROUP_COMMIT_OFF_MODE = "off_mode";
 }
