@@ -35,9 +35,9 @@ import com.ververica.cdc.debezium.DebeziumDeserializationSchema;
 import com.ververica.cdc.debezium.JsonDebeziumDeserializationSchema;
 import com.ververica.cdc.debezium.table.DebeziumOptions;
 import org.apache.doris.flink.catalog.doris.DataModel;
-import org.apache.doris.flink.deserialization.DorisJsonDebeziumDeserializationSchema;
 import org.apache.doris.flink.tools.cdc.DatabaseSync;
 import org.apache.doris.flink.tools.cdc.SourceSchema;
+import org.apache.doris.flink.tools.cdc.deserialize.DorisJsonDebeziumDeserializationSchema;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
@@ -230,8 +230,7 @@ public class MysqlDatabaseSync extends DatabaseSync {
 
     @Override
     public String getTableListPrefix() {
-        String databaseName = config.get(MySqlSourceOptions.DATABASE_NAME);
-        return databaseName;
+        return config.get(MySqlSourceOptions.DATABASE_NAME);
     }
 
     /**
